@@ -25,7 +25,7 @@ sizes = {
     "LY3": ("LY0", "LY1", "LY2"),
     "GL4": ("GL0", "GL1", "GL2", "GL3"),
     "TY2": ("TY0", "TY1"),
-    "CY2": ("CY0", "CY1"),
+    "CY3": ("CY0", "CY1", "CY2"),
     "GD4": ("GD0", "GD1", "GD2", "GD3"),
     "PA4": ("PA0", "PA1", "PA2", "PA3"),
     "AR4": ("AR0", "AR1", "AR2", "AR3"),
